4 ms·
> you will discover to your amazement that resulting code became 7-10% slower on V8 I found both V8 and Ion to be >10% faster using array. I no longer have th
by bsdetector 13y ago
> you will discover to your amazement that resulting code became 7-10% slower on V8
I found both V8 and Ion to be >10% faster using array. I no longer have the results but IIRC it was 11% for V8 and 14% for Ion on i7 (ivy bridge). I moved remove() from OrderedCollection to Array prototype. Perhaps you made some other change.
> Overall it seems that this is irrelevant in the large picture of things: Dart VM is around 195% of V8,
There are 3 benchmarks. That is not enough data to say anything meaningful about Dart VM performance.
> dart2js is somewhere around 100%.
How can dart2js results be compared to the original JS if the data structures used are different? It makes no sense.
- mraleph 13y ago> Perhaps you made some other change. I tried with both global remove and remove on the Array prototype. V8 has recently improved DeltaBlue score by, I think, ~6% so it can be that before this improvement OrderedCollection overhead was more noticeable. (some of that improvement comes from tweaks in the inlining heuristics AFAIK). > There are 3 benchmarks. I was stating performance numbers for DeltaBlue only. Sorry for not being clear. > How can dart2js results be compared to the original JS if the data structures used are different? Substract 5%. dart2js is around 95%. Does it make sense now?